<?php

/**
 * @package     AsupanViral Top 10 Video Fetcher
 * @version     3.1.0
 * @author      Tiann Dev
 * @license     MIT License
 * @description Package ini dirancang untuk mengambil daftar video dari API AsupanViral dan menampilkan 10 video terpopuler berdasarkan jumlah tampilan. Fitur ini mencakup pemuatan data yang efisien, pengurutan berdasarkan tampilan, dan penanganan kesalahan dalam pemrosesan data JSON.
 * 
 * @license MIT License
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
 
header('Content-Type: application/json');

$config = require './config.php';
$apiKey = $config['apikey_lulustream'] ?? '';
$fld_id = $config['folder_id'] ?? '';

$url = "https://lulustream.com/api/file/list?key={$apiKey}&fld_id={$fld_id}&per_page=5000";

$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, $url);
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/json']);
curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
$response = curl_exec($ch);

if (curl_errno($ch)) {
    echo json_encode(['success' => false, 'message' => curl_error($ch)]);
} else {
    $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    if ($http_code == 200) {
        $data = json_decode($response, true);
        if (json_last_error() === JSON_ERROR_NONE) {
            if (isset($data['result']['files']) && is_array($data['result']['files'])) {
                usort($data['result']['files'], function($a, $b) {
                    return $b['views'] <=> $a['views'];
                });
                $top10 = array_slice($data['result']['files'], 0, 10);
                echo json_encode(['success' => true, 'data' => $top10]);
            } else {
                echo json_encode(['success' => false, 'message' => 'No files found or files key missing']);
            }
        } else {
            echo json_encode(['success' => false, 'message' => 'JSON decode error: ' . json_last_error_msg()]);
        }
    } else {
        echo json_encode(['success' => false, 'message' => 'HTTP Status Code: ' . $http_code]);
    }
}
curl_close($ch);

?>